
set echo on

CREATE TABLE trades_staging
( trade_id           NUMBER
, leg_no             NUMBER
, valuation_date     DATE
, product_type       VARCHAR2(10)
, counterparty       VARCHAR2(30)
, trade_timestamp    TIMESTAMP
, trading_book       VARCHAR2(30)
, maturity_date      DATE
, trade_amount       NUMBER
, currency           VARCHAR2(3)
, trade_price        NUMBER
, market_value       NUMBER
)
PARALLEL;

INSERT INTO trades_staging
SELECT object_id                                       AS trade_id
,      ROW_NUMBER() OVER 
          (PARTITION BY object_id ORDER BY 1)          AS leg_no
,      TRUNC(SYSDATE)-1                                AS valuation_date
,      SUBSTR(object_type,1,10)                        AS product_type
,      owner                                           AS counterparty
,      TO_TIMESTAMP(timestamp,'YYYY-MM-DD:HH24:MI:SS') AS trade_timestamp
,      object_type                                     AS trading_book
,      created + MOD(object_id,500)                    AS maturity_date
,      ABS(DBMS_RANDOM.RANDOM)                         AS trade_amount
,      'GBP'                                           AS currency
,      DBMS_RANDOM.VALUE                               AS trade_price
,      ABS(DBMS_RANDOM.RANDOM)                         AS market_value
FROM   all_objects
,     (SELECT NULL FROM all_objects WHERE ROWNUM <= 2)
WHERE  object_id IS NOT NULL;

COMMIT;
 
